==> dde-network-core_1.0.34.orig.tar.xz: dde-network-core-1.0.34/dss-network-plugin/translations/dss-network-plugin_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nouveau message</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connecté</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Connexion filaire</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Point d&apos;accès</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocole</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Type de sécurité</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bande</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de réseau</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primaire</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Vitesse</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Périphérique désactivé </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connecté mais pas d’accès internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Pas connecté</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Câble réseau débranché</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion en cours</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtention d&apos;adresse IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connecté</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Déconnecté</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Échoué</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Réseau filaire %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Réseau sans fil %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Périphérique désactivé </translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Câble réseau débranché</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Pas connecté</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion en cours</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connecté mais pas d’accès internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>La connexion a échoué</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Désactiver la connexion filaire</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activer la connexion filaire</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Désactiver la connexion sans fil</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activer la connexion sans fil</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Désactiver le réseau</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activer le réseau</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Paramètres réseau</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dss-network-plugin/translations/dss-network-plugin_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nouveau message</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Connexion %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connecté</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 déconnecté</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Impossible de se connecter à %1, veuillez vérifier votre routeur ou votre câble réseau.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Impossible de se connecter à %1, veuillez vous rapprocher du routeur sans fil</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>La connexion a échoué, impossible de se connecter à %1, mot de passe erroné</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Le mot de passe est requis pour se connecter à %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Le réseau WLAN %1 802.11 est introuvable</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Connexion filaire</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Point d&apos;accès</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocole</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Type de sécurité</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bande</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de réseau</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primaire</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Vitesse</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Périphérique désactivé </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connecté mais pas d’accès internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Pas connecté</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Câble réseau débranché</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion en cours</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtention d&apos;adresse IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connecté</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Déconnecté</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflit IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Échoué</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtenir l&apos;adresse</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Réseau filaire %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Réseau sans fil %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Périphérique désactivé </translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Câble réseau débranché</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Pas connecté</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion en cours</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connecté mais pas d’accès internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>La connexion a échoué</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflit IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Désactiver la connexion filaire</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activer la connexion filaire</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Désactiver la connexion sans fil</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activer la connexion sans fil</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Désactiver le réseau</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activer le réseau</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Paramètres réseau</translation>
    </message>
</context>
</TS>
